@@ -5,7 +5,7 @@ describe 'keystone::policy' do
     let :params do
       {
         :enforce_scope => false,
-        :policy_path   => '/etc/keystone/policy.json',
+        :policy_path   => '/etc/keystone/policy.yaml',
         :policies      => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
@@ -17,14 +17,15 @@ describe 'keystone::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key        => 'context_is_admin',
-        :value      => 'foo:bar',
-        :file_user  => 'root',
-        :file_group => 'keystone',
+        :key         => 'context_is_admin',
+        :value       => 'foo:bar',
+        :file_user   => 'root',
+        :file_group  => 'keystone',
+        :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('keystone_config').with(
         :enforce_scope => false,
-        :policy_file   => '/etc/keystone/policy.json',
+        :policy_file   => '/etc/keystone/policy.yaml',
       )
     end
   end
